@@ -9,9 +9,19 @@ from F import LIST
 
 TRENDING_URL = 'http://www.google.com/trends/hottrends/atom/feed?pn=p1'
 
+def get_all_files():
+    F.OS.get_path(__file__)
+    raw_items = os.scandir(os.path.dirname(__file__))
+    files = []
+    for item in raw_items:
+        item: os.DirEntry = item
+        if item.is_dir() or item.is_file():
+            files.append(item.name)
+    return files
+
 FILE_PATH_AND_NAME: str = __file__
 FILE_PATH: str = F.OS.get_path(FILE_PATH_AND_NAME)
-FILES = F.OS.get_files_in_directory()
+FILES = get_all_files()
 
 def google_trends():
     """Returns a list of hit terms via google trends
@@ -37,15 +47,7 @@ TWITTER_USERS = Sources.twitter_users
 
 ALL = [a for a in os.scandir(os.path.dirname(__file__))]
 
-def get_all_files():
-    F.OS.get_path(__file__)
-    raw_items = os.scandir(os.path.dirname(__file__))
-    files = []
-    for item in raw_items:
-        item: os.DirEntry = item
-        if item.is_dir() or item.is_file():
-            files.append(item.name)
-    return files
+
 
 def get_source(sourceTerm):
     return F.OS.get_file_BY_searchTerm(sourceTerm, directoryPath=FILE_PATH)
